#!/usr/bin/env node
/********************************************************* {COPYRIGHT-TOP} ***
 * Licensed Materials - Property of IBM
 * 5725-Z22, 5725-Z63, 5725-U33, 5725-Z63
 *
 * (C) Copyright IBM Corporation 2016, 2017
 *
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 ********************************************************** {COPYRIGHT-END} **/
// Node module: apiconnect-cli-apis

var g = require('strong-globalize')();

module.exports = {
  name: 'apis',
  version: require('../package.json').version,
  path: __filename,
  isBuiltin: true,
  topics: getTopics,
};

function getTopics() {
  return [ {
    name: 'apis',
    commands: [
      {
        command: 'clone',
        loginRequired: 'catalog',
        type: 'catalog',
        defaultType: true,
        helpInfo: g.f('apic_apis_clone_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').apisClone(opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs' },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs' },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.host', required: true },
          { name: 'all-catalogs', rune: 'C', type: 'boolean' },
          { name: 'all-organizations', rune: 'O', type: 'boolean' },
        ],
      },
      {
        command: 'get <apiName[:version]>',
        loginRequired: 'catalog',
        type: 'catalog',
        defaultType: true,
        helpInfo: g.f('apic_apis_get_help.txt'),
        action: function(apiNameVersion, opts) {
          return require('./plugin-impl').apisGet(apiNameVersion, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'list',
        aliases: [ 'apis' ],
        loginRequired: 'catalog',
        type: 'catalog',
        defaultType: true,
        helpInfo: g.f('apic_apis_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').apisList(opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs' },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs' },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.host', required: true },
          { name: 'all-catalogs', rune: 'C', type: 'boolean' },
          { name: 'all-organizations', rune: 'O', type: 'boolean' },
        ],
      },
      {
        command: 'pull <apiName[:version]>',
        loginRequired: 'catalog',
        type: 'catalog',
        defaultType: true,
        helpInfo: g.f('apic_apis_pull_help.txt'),
        action: function(apiNameVersion, opts) {
          return require('./plugin-impl').apisPull(apiNameVersion, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'set <apiName[:version]>',
        loginRequired: 'catalog',
        type: 'catalog',
        defaultType: true,
        helpInfo: g.f('apic_apis_set_help.txt'),
        action: function(apiNameVersion, opts) {
          return require('./plugin-impl').apisSet(apiNameVersion, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'hostname', default: '$APIC_CONFIG$.catalog.host', required: true },
          { name: 'status', type: 'enum', values: [ 'online', 'offline' ] },
        ],
      },
      {
        command: 'clone',
        loginRequired: 'space',
        type: 'space',
        helpInfo: g.f('apic_apis_clone_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').apisClone(opts);
        },
        options: [
          { name: 'space', type: 'name', default: '$APIC_CONFIG$.space.data.spaces', required: true },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.space.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.space.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'host', default: '$APIC_CONFIG$.space.host', required: true },
        ],
      },
      {
        command: 'get <apiName[:version]>',
        loginRequired: 'space',
        type: 'space',
        helpInfo: g.f('apic_apis_get_help.txt'),
        action: function(apiNameVersion, opts) {
          return require('./plugin-impl').apisGet(apiNameVersion, opts);
        },
        options: [
          { name: 'space', type: 'name', default: '$APIC_CONFIG$.space.data.spaces', required: true },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.space.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.space.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'host', default: '$APIC_CONFIG$.space.host', required: true },
        ],
      },
      {
        command: 'list',
        aliases: [ 'apis' ],
        loginRequired: 'space',
        type: 'space',
        helpInfo: g.f('apic_apis_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').apisList(opts);
        },
        options: [
          { name: 'space', type: 'name', default: '$APIC_CONFIG$.space.data.spaces', required: true },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.space.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.space.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'host', default: '$APIC_CONFIG$.space.host', required: true },
        ],
      },
      {
        command: 'pull <apiName[:version]>',
        loginRequired: 'space',
        type: 'space',
        helpInfo: g.f('apic_apis_pull_help.txt'),
        action: function(apiNameVersion, opts) {
          return require('./plugin-impl').apisPull(apiNameVersion, opts);
        },
        options: [
          { name: 'space', type: 'name', default: '$APIC_CONFIG$.space.data.spaces', required: true },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.space.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.space.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'host', default: '$APIC_CONFIG$.space.host', required: true },
        ],
      },
      {
        command: 'set <apiName[:version]>',
        loginRequired: 'space',
        type: 'space',
        helpInfo: g.f('apic_apis_set_help.txt'),
        action: function(apiNameVersion, opts) {
          return require('./plugin-impl').apisSet(apiNameVersion, opts);
        },
        options: [
          { name: 'space', type: 'name', default: '$APIC_CONFIG$.space.data.spaces', required: true },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.space.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.space.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'host', default: '$APIC_CONFIG$.space.host', required: true },
          { name: 'status', type: 'enum', values: [ 'online', 'offline' ] },
        ],
      },
    ],
  } ];
};

